pub struct TestTimer {
pub name: Ustr,
pub interval_ns: NonZeroU64,
pub start_time_ns: UnixNanos,
pub stop_time_ns: Option<UnixNanos>,
pub fire_immediately: bool,
/* private fields */
}Expand description
A test timer for user with a TestClock.
TestTimer simulates time progression in a controlled environment,
allowing for precise control over event generation in test scenarios.
Threading
The timer mutates its internal state and should only be used from its owning thread.
Fields
name: UstrThe name of the timer.
interval_ns: NonZeroU64The interval between timer events in nanoseconds.
start_time_ns: UnixNanosThe start time of the timer in UNIX nanoseconds.
stop_time_ns: Option<UnixNanos>The optional stop time of the timer in UNIX nanoseconds.
fire_immediately: boolIf the timer should fire immediately at start time.
Implementations
Sourceimpl TestTimer
impl TestTimer
Sourcepub fn new(
name: Ustr,
interval_ns: NonZeroU64,
start_time_ns: UnixNanos,
stop_time_ns: Option<UnixNanos>,
fire_immediately: bool,
) -> Self
pub fn new( name: Ustr, interval_ns: NonZeroU64, start_time_ns: UnixNanos, stop_time_ns: Option<UnixNanos>, fire_immediately: bool, ) -> Self
Sourcepub const fn next_time_ns(&self) -> UnixNanos
pub const fn next_time_ns(&self) -> UnixNanos
Returns the next time in UNIX nanoseconds when the timer will fire.
Sourcepub const fn is_expired(&self) -> bool
pub const fn is_expired(&self) -> bool
Returns whether the timer is expired.
pub const fn pop_event(&self, event_id: UUID4, ts_init: UnixNanos) -> TimeEvent
Sourcepub fn advance(
&mut self,
to_time_ns: UnixNanos,
) -> impl Iterator<Item = TimeEvent> + '_
pub fn advance( &mut self, to_time_ns: UnixNanos, ) -> impl Iterator<Item = TimeEvent> + '_
Advance the test timer forward to the given time, generating a sequence
of events. A TimeEvent is appended for each time a next event is
<= the given to_time_ns.
This allows testing of multiple time intervals within a single step.